@@ -2363,8 +2363,6 @@ EXPORT(void) init_openal(void) {
     PyModule_AddIntConstant(m, "AL_CHANNELS", AL_CHANNELS);
     PyModule_AddIntConstant(m, "AL_SIZE", AL_SIZE);
     PyModule_AddIntConstant(m, "AL_UNUSED", AL_UNUSED);
-    PyModule_AddIntConstant(m, "AL_QUEUED", AL_QUEUED);
-    PyModule_AddIntConstant(m, "AL_CURRENT", AL_CURRENT);
     PyModule_AddIntConstant(m, "AL_NO_ERROR", AL_NO_ERROR);
     PyModule_AddIntConstant(m, "AL_INVALID_NAME", AL_INVALID_NAME);
     PyModule_AddIntConstant(m, "AL_ILLEGAL_ENUM", AL_ILLEGAL_ENUM);
